" Vim syntax file
" Language:	OpenFOAM Case Files
" Maintainer:	Tobias Holzmann
" Last Change:  March 23, 2012
" Version:	1.0

if exists("b:current_syntax")
 finish
endif

" OpenFOAM Comments
syntax 	region  ofCommentLine  start=/\/\// end=/\n/
syntax 	region	ofCommentBlock start=/\/\*/  end=/\*\// 
highlight link	ofCommentLine  Comment
highlight link 	ofCommentBlock Comment


" OpenFOAM bool
syntax 	keyword	ofBool true false yes no on YES NO none off 
highlight link 	ofBool Boolean

" OpenFOAM include
syntax	match   ofInclude "\#include"
highlight link	ofInclude Identifier

" OpenFOAM Operators and Syntax
syntax 	match	ofOperator "+\|-\|\*\|;\|:\|,\|<\|>\|&\||\|!\|\~\|%\|=\|)\|(\|{\|}\|\.\|\[\|\]\|\""
highlight link 	ofOperator Operator

" OpenFOAM Header
syntax	region	ofHeader start=/FoamFile/ end=/\}/
highlight link	ofHeader Identifier 

" OpenFOAM Numbers
syntax	match	ofNumbers "[-]\+[0-9]\+\|[0-9]\+[\.\-e]\+[0-9]\+\|[0-9]\+"
highlight link	ofNumbers Identifier

" OpenFOAM Solver        
syn	match	ofSolver "[a-zA-Z]\+Foam"
highlight link	ofSolver Statement



""""""""""""""""""""""""""""""""""""
"      OpenFOAM System folder      " 
""""""""""""""""""""""""""""""""""""

	" snappyHexMeshDict

syntax 	keyword	ofSnappyHexMeshType type name level file mode inside outside distance nSurfaceLayers min max
highlight link 	ofSnappyHexMeshType Type 

syntax 	keyword ofSnappyHexMeshGroups geometry refinementRegions refinementSurfaces searchableBox searchableSphere triSurfaceMesh maxLocalCells maxGlobalCells minRefinementCells nCellsBetweenLevels locationInMesh allowFreeStandingZoneFaces nSmoothPatch tolerance nSolveIter nRelaxIter nFeatureSnapIter expansionRatio finalLayerThickness minThickness nGrow featureAngle nRelaxIter nSmoothSurfaceNormals features resolveFeatureAngle relativeSize nSmoothNormals nSmoothThickness maxFaceThicknessRatio maxThicknessToMedialRatio minMedianAxisAngle nBufferCellsNoExtrude nLayerIter nRelaxedIter maxNonOrtho maxBoundarySkewness maxInternalSkewness maxConcave minVol minTetQuality minArea minTwist minDeterminant minFaceWeight minVolRatio minTriangleTwist nSmoothScale errorReduction debug mergeTolerance
highlight link 	ofSnappyHexMeshGroups Constant

syntax	match	ofSTL "[a-zA-Z0-9]*.stl"
highlight link 	ofSTL Boolean

syntax 	keyword ofSnappyHexMeshKeywords castellatedMesh snap addLayers addLayersControls castellatedMeshControls snapControls meshQualityControls relaxed region layers features refinementSurfaces refinementRegions
highlight link 	ofSnappyHexMeshKeywords Statement

	" controlDict  

syn	keyword	ofControlDictConst startFrom stopAt deltaT writeControl writeInterval purgeWrite writeFormat writePrecision writeCompression timeFormat timePrecision graphFormat runTimeModifiable libs adjustTimeStep maxCo maxAlphaCo maxDeltaT application UName trackForward setFormat outputControl functionObjectLibs fields lifeTime nSubCycle cloudName seedSampleSet
highlight link 	ofControlDictConst Constant

syn	keyword	ofControlDictAttribut firstTime latestTime writeNoew noWriteNow nextWrite timeStep runTime adjustableRunTime cpuTime clockTime ascii binary uncompressed compressed fixed scientific general raw gnuplot xmgr jplot outputTime vtk particleTracks axis start end nPoints
highlight link 	ofControlDictAttribut Type

syn 	match	ofSpecialAttribut " startTime\| endTime"
highlight link	ofSpecialAttribut Type

syn	match	ofSpecialAttribut2 "^startTime\|^endTime"
highlight link	ofSpecialAttribut2 Constant

syn	keyword	ofFunctions functions streamLines uniformCoeffs forceCoeffs cuttingPlane readFields
highlight link  ofFunctions Statement

		" ---> Function Streamline

syn	keyword ofFunctionStreamline streamLine 
highlight link  ofFunctionStreamline Boolean

		" ---> Function forceCoeffs

syn	keyword	ofFunctionForceCoeffs pitch
highlight link	ofFunctionForceCoeffs Boolean





"""""""""""""""""""""""""""""""""
"    OpenFOAM 0 Time Folder     "
"""""""""""""""""""""""""""""""""

	" Boundary Types

syn	keyword	ofDict0BoundaryType activeBaffleVelocity activePressureForceBaffleVelocity advective buoyantPressure codedFixedValue cylindricalInletVelocity directMappedField directMappedFixedInternalValue directMappedFixedPushedInternalValue directMappedFixedValue directMappedFlowRate directMappedVelocityFluxFixedValue fan fanPressure fixedFluxPressure fixedInternalValueFvPatchField fixedJump fixedNormalSlip fixedPressureCompressibleDensity flowRateInletVelocity fluxCorrectedVelocity freestream freestreamPressure inletOutlet inletOutletTotalTemperature movingWallVelocity oscillatingFixedValue outletInlet outletMappedUniformInlet partialSlip pressureDirectedInletOutletVelocity pressureDirectedInletVelocity pressureInletOutletVelocity pressureInletUniformVelocity pressureInletVelocity pressureNormalInletOutletVelocity rotatingPressureInletOutletVelocity rotatingTotalPressure rotatingWallVelocity selfContainedDirectMapped skript slip supersonicFreestream surfaceNormalFixedValue swirlFlowRateInletVelocity syringePressure timeVaryingFlowRateInletVelocity timeVaryingMappedFixedValue timeVaryingUniformFixedValue timeVaryingUniformTotalPressure totalPressure totalTemperature translatingWallVelocity turbulentInlet turbulentIntensityKineticEnergyInlet uniformDensityHydrostaticPressure uniformFixedValue waveTransmissive groovyBC zeroGradient fixedValue kqRWallFunction epsilonWallFunction omegaWallFunction nutkWallFunction turbulentMixingLengthDissipationRateInlet timeVaryingTotalPressure basicSymmetry coupled fixedGradient mixed calculated porousBafflePressure
highlight link  ofDict0BoundaryType Boolean 

	" Boundary Variables

syn	keyword ofDict0Value uniform p0 gamma phi U rho psi intensity p k epsilon p_rgh omega T R nut 
highlight link	ofDict0Value Constant

	" Boundary Init Values

syn	keyword ofDict0Variables value inletValue outletValue mixingLength 
highlight link  ofDict0Variables Type

	" Boundary Special Value $internalField

syn 	match	ofInternalField "\$*internalField\|dimensions\|boundaryField"
highlight link	ofInternalField Statement




"""""""""""""""""""""""""""""""""
"   OpenFOAM constant Folder    "
"""""""""""""""""""""""""""""""""

	" PolyMesh - Boundary

syn	keyword ofConstantBoundaryDict patch wall symmetryPlane empty cyclic inlet; outlet;
highlight link  ofConstantBoundaryDict Boolean

	" PolyMesh - blockMeshDict

syn	keyword	ofConstantblockMeshDict	vertices blocks edges boundary mergePatchPairs
highlight link	ofConstantblockMeshDict Statement

syn	keyword	ofConstantblockMeshDictSpec convertToMeters hex simpleGrading
highlight link	ofConstantblockMeshDictSpec Constant

	" RASProperties 

syn	keyword	ofConstantRASProperties printCoeffs turbulence
highlight link  ofConstantRASProperties Constant

syn	match 	ofConstantRASPropertiesSpec "^RASModel"
highlight link	ofConstantRASPropertiesSpec constant

syn 	keyword	ofConstantRASOptions kOmega kOmegaSST kEpsilon laminar qZeta realizeableKE SpalartAllmaras RNGkEpsilon NonelinearKEShih LRR LamBremhorsteKE LounderGibsonRSTM LounderSharmaKE LienCubicKE LienCubicKELowRe LienLeschzinerLowRe
highlight link  ofConstantRASOptions Boolean

	" turbulenceProperties

syn	keyword ofConstantturbProperties simulationType
highlight link	ofConstantturbProperties constant

syn	match	ofConstantturbPropertiesType " RASModel\| LESModel"
highlight link  ofConstantturbPropertiesType Boolean


	" transportProperties 

syn 	keyword	ofTransportPropertiesConst transportModel
highlight link  ofTransportPropertiesConst constant

syn	keyword ofTransportPropertiesModel Newtonian BirdCarreau CrossPowerLaw powerLaw HerschelBulkley
highlight link	ofTransportPropertiesModel Boolean

syn	keyword	ofTransportPropertiesFunction CrossPowerLawCoeffs BirdCarreauCoeffs 
highlight link  ofTransportPropertiesFunction Statement

syn 	keyword	ofTransportPropertiesVariables nu k nuInf nu0 n m
highlight link  ofTransportPropertiesVariables constant

"""""""""""""""""""""""""""""""""
"""""""""""""""""""""""""""""""""
let b:current_syntax = "openfoam"
